@@ -43,6 +43,7 @@ from wallee.api.payment_method_service_api import PaymentMethodServiceApi
 from wallee.api.payment_processor_configuration_service_api import PaymentProcessorConfigurationServiceApi
 from wallee.api.payment_processor_service_api import PaymentProcessorServiceApi
 from wallee.api.payment_terminal_service_api import PaymentTerminalServiceApi
+from wallee.api.payment_terminal_till_service_api import PaymentTerminalTillServiceApi
 from wallee.api.permission_service_api import PermissionServiceApi
 from wallee.api.refund_comment_service_api import RefundCommentServiceApi
 from wallee.api.refund_service_api import RefundServiceApi
@@ -106,7 +107,7 @@ from wallee.models.abstract_debt_collection_case_update import AbstractDebtColle
 from wallee.models.abstract_human_user_update import AbstractHumanUserUpdate
 from wallee.models.abstract_payment_link_update import AbstractPaymentLinkUpdate
 from wallee.models.abstract_refund_comment_active import AbstractRefundCommentActive
-from wallee.models.abstract_shopify_subscription_product_active import AbstractShopifySubscriptionProductActive
+from wallee.models.abstract_shopify_subscription_product_update import AbstractShopifySubscriptionProductUpdate
 from wallee.models.abstract_space_update import AbstractSpaceUpdate
 from wallee.models.abstract_subscriber_update import AbstractSubscriberUpdate
 from wallee.models.abstract_subscription_affiliate_update import AbstractSubscriptionAffiliateUpdate
@@ -270,16 +271,22 @@ from wallee.models.role import Role
 from wallee.models.sales_channel import SalesChannel
 from wallee.models.scope import Scope
 from wallee.models.server_error import ServerError
+from wallee.models.shopify_additional_line_item_data import ShopifyAdditionalLineItemData
 from wallee.models.shopify_integration import ShopifyIntegration
-from wallee.models.shopify_integration_app_version import ShopifyIntegrationAppVersion
+from wallee.models.shopify_integration_payment_app_version import ShopifyIntegrationPaymentAppVersion
+from wallee.models.shopify_integration_subscription_app_version import ShopifyIntegrationSubscriptionAppVersion
 from wallee.models.shopify_recurring_order_state import ShopifyRecurringOrderState
 from wallee.models.shopify_recurring_order_update_request import ShopifyRecurringOrderUpdateRequest
 from wallee.models.shopify_subscriber import ShopifySubscriber
+from wallee.models.shopify_subscriber_creation import ShopifySubscriberCreation
 from wallee.models.shopify_subscriber_state import ShopifySubscriberState
 from wallee.models.shopify_subscription import ShopifySubscription
+from wallee.models.shopify_subscription_address_create import ShopifySubscriptionAddressCreate
 from wallee.models.shopify_subscription_billing_interval_unit import ShopifySubscriptionBillingIntervalUnit
-from wallee.models.shopify_subscription_edit_model_item import ShopifySubscriptionEditModelItem
-from wallee.models.shopify_subscription_edit_model_tax_line import ShopifySubscriptionEditModelTaxLine
+from wallee.models.shopify_subscription_creation_request import ShopifySubscriptionCreationRequest
+from wallee.models.shopify_subscription_model_billing_configuration import ShopifySubscriptionModelBillingConfiguration
+from wallee.models.shopify_subscription_model_item import ShopifySubscriptionModelItem
+from wallee.models.shopify_subscription_model_tax_line import ShopifySubscriptionModelTaxLine
 from wallee.models.shopify_subscription_product import ShopifySubscriptionProduct
 from wallee.models.shopify_subscription_product_pricing_option import ShopifySubscriptionProductPricingOption
 from wallee.models.shopify_subscription_product_state import ShopifySubscriptionProductState
@@ -289,6 +296,7 @@ from wallee.models.shopify_subscription_suspension_create import ShopifySubscrip
 from wallee.models.shopify_subscription_suspension_initiator import ShopifySubscriptionSuspensionInitiator
 from wallee.models.shopify_subscription_suspension_state import ShopifySubscriptionSuspensionState
 from wallee.models.shopify_subscription_suspension_type import ShopifySubscriptionSuspensionType
+from wallee.models.shopify_subscription_update_addresses_request import ShopifySubscriptionUpdateAddressesRequest
 from wallee.models.shopify_subscription_update_request import ShopifySubscriptionUpdateRequest
 from wallee.models.shopify_subscription_version import ShopifySubscriptionVersion
 from wallee.models.shopify_subscription_version_item import ShopifySubscriptionVersionItem
@@ -350,9 +358,11 @@ from wallee.models.subscription_suspension_create import SubscriptionSuspensionC
 from wallee.models.subscription_suspension_reason import SubscriptionSuspensionReason
 from wallee.models.subscription_suspension_state import SubscriptionSuspensionState
 from wallee.models.subscription_update import SubscriptionUpdate
+from wallee.models.subscription_update_request import SubscriptionUpdateRequest
 from wallee.models.subscription_version import SubscriptionVersion
 from wallee.models.subscription_version_state import SubscriptionVersionState
 from wallee.models.tax import Tax
+from wallee.models.tax_calculation import TaxCalculation
 from wallee.models.tax_class import TaxClass
 from wallee.models.tax_create import TaxCreate
 from wallee.models.tenant_database import TenantDatabase
@@ -364,6 +374,7 @@ from wallee.models.tokenization_mode import TokenizationMode
 from wallee.models.transaction import Transaction
 from wallee.models.transaction_aware_entity import TransactionAwareEntity
 from wallee.models.transaction_comment import TransactionComment
+from wallee.models.transaction_completion_behavior import TransactionCompletionBehavior
 from wallee.models.transaction_completion_mode import TransactionCompletionMode
 from wallee.models.transaction_completion_request import TransactionCompletionRequest
 from wallee.models.transaction_completion_state import TransactionCompletionState
@@ -418,8 +429,8 @@ from wallee.models.refund_comment_active import RefundCommentActive
 from wallee.models.refund_comment_create import RefundCommentCreate
 from wallee.models.shopify_recurring_order import ShopifyRecurringOrder
 from wallee.models.shopify_subscription_address import ShopifySubscriptionAddress
-from wallee.models.shopify_subscription_product_active import ShopifySubscriptionProductActive
 from wallee.models.shopify_subscription_product_create import ShopifySubscriptionProductCreate
+from wallee.models.shopify_subscription_product_update import ShopifySubscriptionProductUpdate
 from wallee.models.shopify_transaction import ShopifyTransaction
 from wallee.models.space_create import SpaceCreate
 from wallee.models.space_update import SpaceUpdate
