@@ -28,6 +28,8 @@ class SubscriptionServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
+
+
         if kwargs.get('async_req'):
             return self.apply_changes_with_http_info(space_id, request, **kwargs)
         else:
@@ -135,6 +137,8 @@ class SubscriptionServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
+
+
         if kwargs.get('async_req'):
             return self.count_with_http_info(space_id, **kwargs)
         else:
@@ -238,6 +242,8 @@ class SubscriptionServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
+
+
         if kwargs.get('async_req'):
             return self.create_with_http_info(space_id, create_request, **kwargs)
         else:
@@ -345,6 +351,8 @@ class SubscriptionServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
+
+
         if kwargs.get('async_req'):
             return self.initialize_with_http_info(space_id, subscription_id, **kwargs)
         else:
@@ -450,6 +458,8 @@ class SubscriptionServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
+
+
         if kwargs.get('async_req'):
             return self.initialize_subscriber_present_with_http_info(space_id, subscription_id, **kwargs)
         else:
@@ -559,6 +569,8 @@ class SubscriptionServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
+
+
         if kwargs.get('async_req'):
             return self.read_with_http_info(space_id, id, **kwargs)
         else:
@@ -666,6 +678,8 @@ class SubscriptionServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
+
+
         if kwargs.get('async_req'):
             return self.search_with_http_info(space_id, query, **kwargs)
         else:
@@ -774,6 +788,8 @@ class SubscriptionServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
+
+
         if kwargs.get('async_req'):
             return self.search_subscription_invoices_with_http_info(space_id, subscription_id, query, **kwargs)
         else:
@@ -889,6 +905,8 @@ class SubscriptionServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
+
+
         if kwargs.get('async_req'):
             return self.terminate_with_http_info(space_id, subscription_id, respect_termination_period, **kwargs)
         else:
@@ -982,6 +1000,123 @@ class SubscriptionServiceApi:
             _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
 
+    def update(self, space_id, subscription_id, request, **kwargs):
+        """update
+
+        This operation allows to update the subscription.
+        This method makes a synchronous HTTP request by default. To make an
+        asynchronous HTTP request, please pass async_req=True
+        >>> thread = api.update(space_id, subscription_id, request, async_req=True)
+        >>> result = thread.get()
+
+        :param async_req bool
+        :param int space_id:  (required)
+        :param int subscription_id:  (required)
+        :param SubscriptionUpdateRequest request:  (required)
+        :return: Subscription
+                 If the method is called asynchronously,
+                 returns the request thread.
+        """
+        kwargs['_return_http_data_only'] = True
+
+
+        if kwargs.get('async_req'):
+            return self.update_with_http_info(space_id, subscription_id, request, **kwargs)
+        else:
+            (data) = self.update_with_http_info(space_id, subscription_id, request, **kwargs)
+            return data
+
+    def update_with_http_info(self, space_id, subscription_id, request, **kwargs):
+        """update
+
+        This operation allows to update the subscription.
+        This method makes a synchronous HTTP request by default. To make an
+        asynchronous HTTP request, please pass async_req=True
+        >>> thread = api.update_with_http_info(space_id, subscription_id, request, async_req=True)
+        >>> result = thread.get()
+
+        :param async_req bool
+        :param int space_id:  (required)
+        :param int subscription_id:  (required)
+        :param SubscriptionUpdateRequest request:  (required)
+        :return: Subscription
+                 If the method is called asynchronously,
+                 returns the request thread.
+        """
+
+        all_params = ['space_id', 'subscription_id', 'request']
+        all_params.append('async_req')
+        all_params.append('_return_http_data_only')
+        all_params.append('_preload_content')
+        all_params.append('_request_timeout')
+
+        params = locals()
+        for key, val in six.iteritems(params['kwargs']):
+            if key not in all_params:
+                raise TypeError(
+                    "Got an unexpected keyword argument '%s'"
+                    " to method update" % key
+                )
+            params[key] = val
+        del params['kwargs']
+        # verify the required parameter 'space_id' is set
+        if ('space_id' not in params or
+                params['space_id'] is None):
+            raise ValueError("Missing the required parameter `space_id` when calling `update`")
+        # verify the required parameter 'subscription_id' is set
+        if ('subscription_id' not in params or
+                params['subscription_id'] is None):
+            raise ValueError("Missing the required parameter `subscription_id` when calling `update`")
+        # verify the required parameter 'request' is set
+        if ('request' not in params or
+                params['request'] is None):
+            raise ValueError("Missing the required parameter `request` when calling `update`")
+
+        collection_formats = {}
+
+        path_params = {}
+
+        query_params = []
+        if 'space_id' in params:
+            query_params.append(('spaceId', params['space_id']))
+        if 'subscription_id' in params:
+            query_params.append(('subscriptionId', params['subscription_id']))
+
+        header_params = {}
+
+        form_params = []
+        local_var_files = {}
+
+        body_params = None
+        if 'request' in params:
+            body_params = params['request']
+        # HTTP header `Accept`
+        header_params['Accept'] = self.api_client.select_header_accept(
+            ['application/json;charset=utf-8'])
+
+        # HTTP header `Content-Type`
+        header_params['Content-Type'] = self.api_client.select_header_content_type(
+            ['application/json;charset=utf-8'])
+
+        # Authentication setting
+        auth_settings = []
+
+        return self.api_client.call_api(
+            '/subscription/update', 'POST',
+            path_params,
+            query_params,
+            header_params,
+            body=body_params,
+            post_params=form_params,
+            files=local_var_files,
+            response_type='Subscription',
+            auth_settings=auth_settings,
+            async_req=params.get('async_req'),
+            _return_http_data_only=params.get('_return_http_data_only'),
+            _preload_content=params.get('_preload_content', True),
+            _request_timeout=params.get('_request_timeout'),
+            collection_formats=collection_formats)
+
     def update_product_version(self, space_id, subscription_id, respect_termination_period, **kwargs):
         """update product version
 
@@ -1000,6 +1135,8 @@ class SubscriptionServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
+
+
         if kwargs.get('async_req'):
             return self.update_product_version_with_http_info(space_id, subscription_id, respect_termination_period, **kwargs)
         else:
