@@ -10,7 +10,7 @@ from .abstract_debt_collection_case_update import AbstractDebtCollectionCaseUpda
 from .abstract_human_user_update import AbstractHumanUserUpdate
 from .abstract_payment_link_update import AbstractPaymentLinkUpdate
 from .abstract_refund_comment_active import AbstractRefundCommentActive
-from .abstract_shopify_subscription_product_active import AbstractShopifySubscriptionProductActive
+from .abstract_shopify_subscription_product_update import AbstractShopifySubscriptionProductUpdate
 from .abstract_space_update import AbstractSpaceUpdate
 from .abstract_subscriber_update import AbstractSubscriberUpdate
 from .abstract_subscription_affiliate_update import AbstractSubscriptionAffiliateUpdate
@@ -174,16 +174,22 @@ from .role import Role
 from .sales_channel import SalesChannel
 from .scope import Scope
 from .server_error import ServerError
+from .shopify_additional_line_item_data import ShopifyAdditionalLineItemData
 from .shopify_integration import ShopifyIntegration
-from .shopify_integration_app_version import ShopifyIntegrationAppVersion
+from .shopify_integration_payment_app_version import ShopifyIntegrationPaymentAppVersion
+from .shopify_integration_subscription_app_version import ShopifyIntegrationSubscriptionAppVersion
 from .shopify_recurring_order_state import ShopifyRecurringOrderState
 from .shopify_recurring_order_update_request import ShopifyRecurringOrderUpdateRequest
 from .shopify_subscriber import ShopifySubscriber
+from .shopify_subscriber_creation import ShopifySubscriberCreation
 from .shopify_subscriber_state import ShopifySubscriberState
 from .shopify_subscription import ShopifySubscription
+from .shopify_subscription_address_create import ShopifySubscriptionAddressCreate
 from .shopify_subscription_billing_interval_unit import ShopifySubscriptionBillingIntervalUnit
-from .shopify_subscription_edit_model_item import ShopifySubscriptionEditModelItem
-from .shopify_subscription_edit_model_tax_line import ShopifySubscriptionEditModelTaxLine
+from .shopify_subscription_creation_request import ShopifySubscriptionCreationRequest
+from .shopify_subscription_model_billing_configuration import ShopifySubscriptionModelBillingConfiguration
+from .shopify_subscription_model_item import ShopifySubscriptionModelItem
+from .shopify_subscription_model_tax_line import ShopifySubscriptionModelTaxLine
 from .shopify_subscription_product import ShopifySubscriptionProduct
 from .shopify_subscription_product_pricing_option import ShopifySubscriptionProductPricingOption
 from .shopify_subscription_product_state import ShopifySubscriptionProductState
@@ -193,6 +199,7 @@ from .shopify_subscription_suspension_create import ShopifySubscriptionSuspensio
 from .shopify_subscription_suspension_initiator import ShopifySubscriptionSuspensionInitiator
 from .shopify_subscription_suspension_state import ShopifySubscriptionSuspensionState
 from .shopify_subscription_suspension_type import ShopifySubscriptionSuspensionType
+from .shopify_subscription_update_addresses_request import ShopifySubscriptionUpdateAddressesRequest
 from .shopify_subscription_update_request import ShopifySubscriptionUpdateRequest
 from .shopify_subscription_version import ShopifySubscriptionVersion
 from .shopify_subscription_version_item import ShopifySubscriptionVersionItem
@@ -254,9 +261,11 @@ from .subscription_suspension_create import SubscriptionSuspensionCreate
 from .subscription_suspension_reason import SubscriptionSuspensionReason
 from .subscription_suspension_state import SubscriptionSuspensionState
 from .subscription_update import SubscriptionUpdate
+from .subscription_update_request import SubscriptionUpdateRequest
 from .subscription_version import SubscriptionVersion
 from .subscription_version_state import SubscriptionVersionState
 from .tax import Tax
+from .tax_calculation import TaxCalculation
 from .tax_class import TaxClass
 from .tax_create import TaxCreate
 from .tenant_database import TenantDatabase
@@ -268,6 +277,7 @@ from .tokenization_mode import TokenizationMode
 from .transaction import Transaction
 from .transaction_aware_entity import TransactionAwareEntity
 from .transaction_comment import TransactionComment
+from .transaction_completion_behavior import TransactionCompletionBehavior
 from .transaction_completion_mode import TransactionCompletionMode
 from .transaction_completion_request import TransactionCompletionRequest
 from .transaction_completion_state import TransactionCompletionState
@@ -322,8 +332,8 @@ from .refund_comment_active import RefundCommentActive
 from .refund_comment_create import RefundCommentCreate
 from .shopify_recurring_order import ShopifyRecurringOrder
 from .shopify_subscription_address import ShopifySubscriptionAddress
-from .shopify_subscription_product_active import ShopifySubscriptionProductActive
 from .shopify_subscription_product_create import ShopifySubscriptionProductCreate
+from .shopify_subscription_product_update import ShopifySubscriptionProductUpdate
 from .shopify_transaction import ShopifyTransaction
 from .space_create import SpaceCreate
 from .space_update import SpaceUpdate
